powered by
This function sends a request to PubChem to retrieve substance data based on the specified parameters.
get_substances(identifier, namespace = "sid", operation = NULL, options = NULL)
An object of class 'PubChemInstanceList' containing all the substance information of requested compounds.
A vector of substance identifiers, either numeric or character.
A character string specifying the namespace of the identifier.
A character string specifying the operation to perform.
A list of additional options for the request.
For more detailed information, please refer to the PubChem PUG REST API documentation.
# \donttest{ subs <- get_substances( identifier = c("aspirin", "ibuprofen"), namespace = "name" ) instance(subs, "aspirin") retrieve(instance(subs, "aspirin"), "source") # }
Run the code above in your browser using DataLab