powered by
Clears request cache entries stored in memory and/or on disk.
pc_cache_clear(cache_dir = NULL, memory = TRUE, disk = TRUE)
Invisibly returns `TRUE`.
Cache directory. If `NULL`, uses configured cache directory.
Logical; clear in-memory cache.
Logical; clear on-disk cache.
Use this helper before reproducible reruns or after changing transport settings when you want to avoid stale cached responses.
tmp_dir <- tempdir() pc_cache_info(cache_dir = tmp_dir) pc_cache_clear(cache_dir = tmp_dir, memory = TRUE, disk = FALSE) pc_cache_info(cache_dir = tmp_dir)
Run the code above in your browser using DataLab