powered by
Reads or updates global defaults used by the next-generation PubChemR transport helpers (timeouts, retries, cache settings, and rate limits).
pc_config(...)
A named list of active configuration values.
Named configuration values to update.
Call with no arguments to inspect the active configuration. Named arguments update only the provided keys and keep all other values unchanged.
cfg <- pc_config() names(cfg) pc_config(rate_limit = cfg$rate_limit)$rate_limit
Run the code above in your browser using DataLab